@@ -82,6 +82,17 @@ namespace Model
     inline GenerateDataKeyPairWithoutPlaintextResult& WithKeyPairSpec(DataKeyPairSpec value) { SetKeyPairSpec(value); return *this;}
     ///@}
 
+    ///@{
+    /**
+     * <p>The identifier of the key material used to encrypt the private key.</p>
+     */
+    inline const Aws::String& GetKeyMaterialId() const { return m_keyMaterialId; }
+    template<typename KeyMaterialIdT = Aws::String>
+    void SetKeyMaterialId(KeyMaterialIdT&& value) { m_keyMaterialIdHasBeenSet = true; m_keyMaterialId = std::forward<KeyMaterialIdT>(value); }
+    template<typename KeyMaterialIdT = Aws::String>
+    GenerateDataKeyPairWithoutPlaintextResult& WithKeyMaterialId(KeyMaterialIdT&& value) { SetKeyMaterialId(std::forward<KeyMaterialIdT>(value)); return *this;}
+    ///@}
+
     ///@{
     
     inline const Aws::String& GetRequestId() const { return m_requestId; }
@@ -104,6 +115,9 @@ namespace Model
     DataKeyPairSpec m_keyPairSpec{DataKeyPairSpec::NOT_SET};
     bool m_keyPairSpecHasBeenSet = false;
 
+    Aws::String m_keyMaterialId;
+    bool m_keyMaterialIdHasBeenSet = false;
+
     Aws::String m_requestId;
     bool m_requestIdHasBeenSet = false;
   };
